%
% AcroFleX (language) customization definition file
% Dr. D. P. Story
% http://www.acrotex.net
%
% Remove the \endinput command below, and redefine each as desired. For languages
% that require special accented characters, the unicode option of hyperref is needed
% for the tooltips. See the AcroFleX manual for more details.
%

%
% ------------------------------------------------------------------;
% These text commands are tooltip messages for the various controls ;
% ------------------------------------------------------------------;
%
% For special accented characters, try entering them directly from your keyboard;
% if that fails, use the unicode option of web (which is just passed to hyperrerf),
% then enter the accented characters using latex commands, like \"{u} for u-umlaut.
%
\tticonFloatGraphScreen{Klicken Sie, um den Grafik-Bildschirm anzuzeigen,
    klicken Sie erneut, um diesen wieder zu schliessen.}
%    
% This message attempts to format the tooltip as an enumerated list.
%
\ttfuncInputField{Geben Sie eine der folgenden Ausdrücke ein:\r
    \space\space1. Eine Funktion in Abhängigkeit von x und der Gestalt f(x);\r
    \space\space2. Eine Polarfunktion in Abhängigkeit von t und der Gestalt f(t);\r
    \space\space3. Ein Satz von Parameterfunktionen in Abhängigkeit von t und der Gestalt f(t);g(t)\r
    \space\space\space\space\space(getrennt durch ein Semikolon);\r
    \space\space4. Eine Liste von Punkten, (a1,b1);(a2,b2);...;(an,bn)\r
    \space\space\space\space\space(jeweils getrennt durch ein Semikolon).}
\ttgraphBtn{Klicken Sie hier, um das zugehörige Schaubild zeichnen zu lassen.} 
\ttgraphClrBtn{Klicken Sie hier, um das Schaubild zu löschen, Shift-klicken Sie, um den Grafik-Bildschirm zu deaktivieren.}
%
\ttfunctionSelect{Geben Sie in \afcurvei1 - \afcurvei4 eine Funktion ein, oder in \afploti1 - \afploti4 eine Liste von Punkten.}
\ttsavedelSelBtn{Klicken Sie hier, um die eingegebene Funktion in der Liste zu speichern, Shift-klicken Sie, um diese Funktion wieder von der Liste zu löschen.}
%
\ttdomMin{Geben Sie den kleinsten Wert der Variablen x ein.}
\ttdomMax{Geben Sie den größten Wert der Variablen x ein.}
\ttrngMin{Geben Sie den kleinsten Wert der Variablen y ein.}
\ttrngMax{Geben Sie den größten Wert der Variablen y ein.}
\ttdomMinP{Geben Sie den kleinsten Wert der Variablen t ein.}
\ttdomMaxP{Geben Sie den größten Wert der Variablen t ein.}
%
\ttnumPoints{Geben Sie die Anzahl der Punkte ein, mit der gezeichnet werden soll.}
\ttamtShift{Geben Sie die Schrittweite ein, mit der horizontal oder vertikal verschoben wird.}
\ttzoomInOut{Klicken Sie zum Auszoomen, Shift-klicken Sie zum Einzoomen.}
%
% ------------------------------------------------------------------;
% Below are some text macros used in creating error messages. They  ;
% may be redefined into better English, or another language.        ;
% ------------------------------------------------------------------;
%
% \defineJSStr is a new command (defined in eforms) that enables you
% to enter unicode, for example, \u00FC is \"{u}. Also within the
% argument string, you can use \r and \t to format your lines as
% needed. Double back slash \\ is converted into single backslash \,
% so for example, \\defineJSStr appears in the dialog box as
% \defineJSStr. The string argument is immediately expanded, so a
% command like \af@defaultNumPoints (in \af@zeroNumberMsg below) gets
% expanded at definition time. Use \protect to delay the expansion
% until the tex compiler finally expands the JS command string.
%
\defineJSStr{\af@badNumberMsg}{%
    Der angegebene Wert ist keine Zahl, bitte geben Sie eine Zahl ein, oder zumindest einen Ausdruck, der eine Zahl ergibt.}
\defineJSStr{\af@negNumberMsg}{%
    Die Anzahl der Punkte ist eine positive ganze Zahl, die nun mit einem positiven Wert versehen wird.}
\defineJSStr{\af@zeroNumberMsg}{%
    Die Anzahl der Punkte ist eine positive ganze Zahl, die nun mit dem Wert \af@defaultNumPoints vorgegeben wird.}
\defineJSStr{\af@negShiftMsg}{%
    Die Schrittweite der Verschiebung ist eine positive Zahl, die nun in eine positive Zahl umgewandelt wird.}
\defineJSStr{\af@zeroShiftMsg}{%
    Die Schrittweite der Verschiebung ist eine positive Zahl, die nun mit 1 vorgegeben ist.}
\defineJSStr{\af@saveDelSelAlerti}{%
    Bitte geben Sie erst eine Funktion in das Textfeld ein, bevor Sie es speichern wollen.}
\defineJSStr{\af@saveDelSelAlertii}{%
    Sie haben keine Punkte zum Zeichnen definiert.}
\defineJSStr{\af@graphBtnAlerti}{Undefinierte Funktionstypen.}
\endinput
