%
% AcroFleX (language) customization definition file
% Dr. D. P. Story
% http://www.acrotex.net
%
% Remove the \endinput command below, and redefine each as desired. For languages
% that require special accented characters, the unicode option of hyperref is needed
% for the tooltips. See the AcroFleX manual for more details.
%
\endinput
%
% ------------------------------------------------------------------;
% These text commands are tooltip messages for the various controls ;
% ------------------------------------------------------------------;
%
% For special accented characters, try entering them directly from your keyboard;
% if that fails, use the unicode option of web (which is just passed to hyperrerf),
% then enter the accented characters using latex commands, like \"{u} for u-umlaut.
%
\tticonFloatGraphScreen{Click to view graphing screen,
    click again to hide graphing screen.}
%    
% This message attempts to format the tooltip as an enumerated list.
%
\ttfuncInputField{Enter any of the following for expressions:\r
    \space\space1. A function of x of the form f(x);\r
    \space\space2. A polar function of t of the form f(t);\r
    \space\space3. A set of parametric functions of t of the form f(t);g(t)\r
    \space\space\space\space\space(separated by a semi-colon);\r
    \space\space4. A list of points, (a1,b1);(a2,b2);...;(an,bn)\r
    \space\space\space\space\space(separated by semi-colons).}
\ttgraphBtn{Press to graph the function}
\ttgraphClrBtn{Click to clear graph, shift-click to deactivate the
    graphing screen}
%    
\ttfunctionSelect{Enter a function on \afcurvei1--\afcurvei4, or
    a list of points on \afploti1--\afploti4.}
\ttsavedelSelBtn{Click to save current function to list, shift-click
    to delete the current function from list}
%    
\ttdomMin{Enter the minimum value for the variable x}
\ttdomMax{Enter the maximum value for the variable x}
\ttrngMin{Enter the minimum value for the variable y}
\ttrngMax{Enter the maximum value for the variable y}
\ttdomMinP{Enter the minimum value for the variable t}
\ttdomMaxP{Enter the maximum value for the variable t}
%
\ttnumPoints{Enter the number of points to plot}
\ttamtShift{Enter the amount to shift, horizontally or vertically}
\ttzoomInOut{Click to zoom out, shift-click to zoom in}
%
% ------------------------------------------------------------------;
% Below are some text macros used in creating error messages. They  ;
% may be redefined into better English, or another language.        ;
% ------------------------------------------------------------------;
%
% \defineJSStr is a new command (defined in eforms) that enables you 
% to enter unicode, for example, \u00FC is \"{u}. Also within the 
% argument string, you can use \r and \t to format your lines as 
% needed. Double back slash \\ is converted into single backslash \, 
% so for example, \\defineJSStr appears in the dialog box as 
% \defineJSStr. The string argument is immediately expanded, so a
% command like \af@defaultNumPoints (in \af@zeroNumberMsg below) gets
% expanded at definition time. Use \protect to delay the expansion
% until the tex compiler finally expands the JS command string.
%
\defineJSStr{\af@badNumberMsg}{%
    The value input does not appear to be a number, please enter a
    number, or an expression that evaluates to a number.}
\defineJSStr{\af@negNumberMsg}{%
    The number of points is a positive integer, changing to a
    positive integer.}
\defineJSStr{\af@zeroNumberMsg}{%
    The number of points is a positive integer, changing to the
    default value of \af@defaultNumPoints.}
\defineJSStr{\af@negShiftMsg}{%
    The amount of shift is a positive number, changing to a positive
    number.}
\defineJSStr{\af@zeroShiftMsg}{%
    The amount of shift is a positive number, changing to the
    default value of 1.}
\defineJSStr{\af@saveDelSelAlerti}{%
    There is nothing in the function input text field.}
\defineJSStr{\af@saveDelSelAlertii}{%
    You have not defined any points to plot}
\defineJSStr{\af@graphBtnAlerti}{Undefined graph types}
\endinput
